@@ -5,7 +5,9 @@ import time
 import subprocess
 from subprocess import CalledProcessError
 import sys
+import re
 import requests
+import yaml
 
 from halo import Halo
 from suite_py.lib import logger
@@ -17,6 +19,7 @@ BASEURL = os.environ["DRONE_SERVER"] = "https://drone-1.prima.it"
 class DroneHandler:
     def __init__(self, config, tokens, repo=None):
         self._token = tokens.drone
+        self._config = config
         os.environ["DRONE_TOKEN"] = self._token
         self._repo = repo
         if repo:
@@ -108,6 +111,49 @@ class DroneHandler:
 
         return None
 
+    def promote(self, build, target, querystring):
+        try:
+            return requests.post(
+                f"{BASEURL}/api/repos/primait/{self._repo}/builds/{build}/promote?target={target}&{querystring}",
+                headers={"Authorization": f"Bearer {self._token}"},
+            ).json()
+        except Exception as e:
+            logger.error(f"Unable to trigger drone build, exiting with error: {e}")
+            sys.exit(-1)
+
+    def promote_production(self, tag, target, querystring):
+        build = self.get_build_from_tag(tag)
+        if build:
+            return self.promote(build, target, querystring)
+
+        logger.error(
+            f"Unable to retrieve drone build for repo {self._repo} with tag {tag}"
+        )
+        sys.exit(-1)
+
+    def get_latest_production_deploy(self):
+        with Halo(text="Contacting drone...", spinner="dots", color="magenta"):
+            REGEX = r"deploy-([a-z]+)-production"
+            try:
+                builds = requests.get(
+                    f"{BASEURL}/api/repos/primait/{self._repo}/builds?per_page=100",
+                    headers={"Authorization": f"Bearer {self._token}"},
+                ).json()
+                builds = [
+                    {
+                        "country": re.findall(REGEX, b["deploy_to"])[0],
+                        "version": b["params"]["DRONE_TAG"],
+                    }
+                    for b in builds
+                    if b["event"] == "promote" and re.search(REGEX, b["deploy_to"])
+                ]
+                return builds
+            except Exception as e:
+                logger.error(f"Unable to retrieve last deploy: {e}")
+                sys.exit(-1)
+
+            return []
+
     def launch_build(self, build):
         return requests.post(
             f"{BASEURL}/api/repos/primait/{self._repo}/builds/{build}",
@@ -162,3 +208,11 @@ class DroneHandler:
         except (CalledProcessError) as e:
             logger.error(f"{self._repo}: unable to sign the .drone.yml {e}")
             sys.exit(-1)
+
+    def parse_yaml(self):
+        repo_path = os.path.join(self._config.user["projects_home"], self._repo)
+        yaml_path = os.path.join(repo_path, ".drone.yml")
+        try:
+            return yaml.load_all(open(yaml_path, "r"), Loader=yaml.FullLoader)
+        except FileNotFoundError:
+            return None
